
"""Core components for open-spark-dlh-dq.

This module includes:
- Data quality models (suite, check, report)
- Registry utilities for validators
- Runner and Reporter implementations
- Built-in validator primitives under `validators`
"""
